@@ -28,12 +28,12 @@ from airflow.providers.qubole.hooks.qubole import QuboleHook
 
 log = logging.getLogger(__name__)
 
-COL_DELIM = '\t'
-ROW_DELIM = '\r\n'
+COL_DELIM = "\t"
+ROW_DELIM = "\r\n"
 
 
 def isint(value) -> bool:
-    """Whether Qubole column are integer"""
+    """Whether Qubole column are integer."""
     try:
         int(value)
         return True
@@ -42,7 +42,7 @@ def isint(value) -> bool:
 
 
 def isfloat(value) -> bool:
-    """Whether Qubole column are float"""
+    """Whether Qubole column are float."""
     try:
         float(value)
         return True
@@ -51,7 +51,7 @@ def isfloat(value) -> bool:
 
 
 def isbool(value) -> bool:
-    """Whether Qubole column are boolean"""
+    """Whether Qubole column are boolean."""
     try:
         return value.lower() in ["true", "false"]
     except ValueError:
@@ -59,7 +59,7 @@ def isbool(value) -> bool:
 
 
 def parse_first_row(row_list) -> list[bool | float | int | str]:
-    """Parse Qubole first record list"""
+    """Parse Qubole first record list."""
     record_list = []
     first_row = row_list[0] if row_list else ""
 
@@ -76,31 +76,31 @@ def parse_first_row(row_list) -> list[bool | float | int | str]:
 
 
 class QuboleCheckHook(QuboleHook, DbApiHook):
-    """Qubole check hook"""
+    """Qubole check hook."""
 
     def __init__(self, context, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.results_parser_callable = parse_first_row
-        if 'results_parser_callable' in kwargs and kwargs['results_parser_callable'] is not None:
-            if not callable(kwargs['results_parser_callable']):
-                raise AirflowException('`results_parser_callable` param must be callable')
-            self.results_parser_callable = kwargs['results_parser_callable']
+        if "results_parser_callable" in kwargs and kwargs["results_parser_callable"] is not None:
+            if not callable(kwargs["results_parser_callable"]):
+                raise AirflowException("`results_parser_callable` param must be callable")
+            self.results_parser_callable = kwargs["results_parser_callable"]
         self.context = context
 
     @staticmethod
     def handle_failure_retry(context) -> None:
-        ti = context['ti']
-        cmd_id = ti.xcom_pull(key='qbol_cmd_id', task_ids=ti.task_id)
+        ti = context["ti"]
+        cmd_id = ti.xcom_pull(key="qbol_cmd_id", task_ids=ti.task_id)
 
         if cmd_id is not None:
             cmd = Command.find(cmd_id)
             if cmd is not None:
-                if cmd.status == 'running':
-                    log.info('Cancelling the Qubole Command Id: %s', cmd_id)
+                if cmd.status == "running":
+                    log.info("Cancelling the Qubole Command Id: %s", cmd_id)
                     cmd.cancel()
 
     def get_first(self, sql):
-        """Get Qubole query first record list"""
+        """Get Qubole query first record list."""
         self.execute(context=self.context)
         query_result = self.get_query_results()
         row_list = list(filter(None, query_result.split(ROW_DELIM)))
@@ -108,12 +108,12 @@ class QuboleCheckHook(QuboleHook, DbApiHook):
         return record_list
 
     def get_query_results(self) -> str | None:
-        """Get Qubole query result"""
+        """Get Qubole query result."""
         if self.cmd is not None:
             cmd_id = self.cmd.id
             self.log.info("command id: %d", cmd_id)
             query_result_buffer = StringIO()
-            self.cmd.get_results(fp=query_result_buffer, inline=True, delim=COL_DELIM, arguments=['true'])
+            self.cmd.get_results(fp=query_result_buffer, inline=True, delim=COL_DELIM, arguments=["true"])
             query_result = query_result_buffer.getvalue()
             query_result_buffer.close()
             return query_result
